@@ -410,6 +410,15 @@ static void connect_me(ENTRY *entry)
 }
 
 
+static void adjust_qos(ITF *itf,struct atm_qos *qos,int null_encap)
+{
+    if (!qos->txtp.max_sdu)
+	qos->txtp.max_sdu = RFC1626_MTU+(null_encap ? 0 : RFC1483LLC_LEN);
+    if (!qos->rxtp.max_sdu)
+	qos->rxtp.max_sdu = RFC1626_MTU+(null_encap ? 0 : RFC1483LLC_LEN);
+}
+
+
 static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
 {
     ENTRY *entry;
@@ -468,6 +477,7 @@ static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
     if (!entry->addr) entry->addr = alloc(sizeof(*addr));
     *entry->addr = *addr;
     entry->qos = entry->itf->qos;
+    adjust_qos(entry->itf,&entry->qos,0);
     for (walk = entry->vccs; walk; walk = walk->next)
 	if (!walk->connecting)
 	    if (set_ip(walk->fd,ip) < 0)
@@ -765,15 +775,6 @@ static int ioctl_delete(ITF *itf,unsigned long ip,int flags)
 }
 
 
-static void adjust_qos(ITF *itf,struct atm_qos *qos,int null_encap)
-{
-    if (!qos->txtp.max_sdu)
-	qos->txtp.max_sdu = RFC1626_MTU+(null_encap ? 0 : RFC1483LLC_LEN);
-    if (!qos->rxtp.max_sdu)
-	qos->rxtp.max_sdu = RFC1626_MTU+(null_encap ? 0 : RFC1483LLC_LEN);
-}
-
-
 int arp_ioctl(int itf_num,unsigned long cmd,struct atmarpreq *req)
 {
     ITF *itf;
@@ -809,7 +810,8 @@ int arp_ioctl(int itf_num,unsigned long cmd,struct atmarpreq *req)
 	    diag(COMPONENT,DIAG_DEBUG,"got SIOCSARP for itf %d, IP %d.%d.%d.%d"
 	      ", ATM %s, flags 0x%x",itf_num,ipp[0],ipp[1],ipp[2],ipp[3],buffer,
 	      req->arp_flags);
-	    if (!req->arp_qos.txtp.traffic_class) req->arp_qos = itf->qos;
+	    if (!req->arp_qos.txtp.traffic_class &&
+	      !req->arp_qos.rxtp.traffic_class) req->arp_qos = itf->qos;
 	    switch (req->arp_ha.sas_family) {
 		case AF_ATMPVC:	
 		    adjust_qos(itf,&req->arp_qos,req->arp_flags & ATF_NULL);
