@@ -53,7 +53,8 @@ void ilmi_loop(int fd, int itf);
 
 void usage(char *name)
 {
-  fprintf(stderr, "usage: %s [-b] [-d] [-l logfile] [-x] <interface>\n", name);
+  fprintf(stderr, "usage: %s [-b] [-d] [-l logfile] [-x] [-q qos] "
+    "<interface>\n", name);
   exit(1);
 }
 
@@ -237,10 +238,12 @@ int main(int argc, char *argv[])
 {
   int fd, opt, itf = 0, bg = 0;
   pid_t pid;
+  const char *qos;
 
   set_application("ilmid");
   set_verbosity(NULL, DIAG_INFO);
-  while((opt = getopt(argc, argv, "bdhl:x")) != EOF)
+  qos = NULL;
+  while((opt = getopt(argc, argv, "bdhl:q:x")) != EOF)
     switch (opt)
       {
       case 'd':
@@ -252,6 +255,9 @@ int main(int argc, char *argv[])
       case 'l':
 	set_logfile(optarg);
 	break;
+      case 'q':
+	qos = optarg;
+	break;
       case 'x':
 	no_var_bindings = 1;
 	break;
@@ -278,7 +284,7 @@ int main(int argc, char *argv[])
     }
   
   InitNibbleMem(512, 512);
-  fd = open_ilmi(itf);
+  fd = open_ilmi(itf,qos);
   ilmi_loop(fd, itf);
   close(fd);
   return 0;
