@@ -246,20 +246,21 @@ int send_message(int fd, Message *message)
 }
 
 
-int open_ilmi(int itf)
+int open_ilmi(int itf,const char *qos_spec)
 {
     struct sockaddr_atmpvc addr;
     struct atm_qos qos;
     int fd;
- 
+
     if((fd = socket(PF_ATMPVC, SOCK_DGRAM, ATM_AAL5)) < 0)
       diag(COMPONENT, DIAG_FATAL, "socket: %s", strerror(errno));
 
     memset(&qos, 0, sizeof(qos));
-    qos.rxtp.traffic_class = ATM_UBR;
-    qos.txtp.traffic_class = ATM_UBR;
     qos.rxtp.max_sdu = MAX_ILMI_MSG;
     qos.txtp.max_sdu = MAX_ILMI_MSG;
+    if (!qos_spec) qos.rxtp.traffic_class = qos.txtp.traffic_class = ATM_UBR;
+    else if (text2qos(qos_spec,&qos,T2Q_DEFAULTS) < 0)
+	    diag(COMPONENT,DIAG_FATAL,"invalid qos: %s",qos_spec);
     if (setsockopt(fd, SOL_ATM, SO_ATMQOS, &qos, sizeof(qos)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"setsockopt SO_ATMQOS: %s",strerror(errno));
 
