@@ -92,6 +92,7 @@ int bufalign = 16*1024;		/* modulo this */
 int atm = 0;			/* 0 = INET, !0 = ATM */
 int pcr = 0;
 int arequipa = 0;
+char *qos_spec = NULL;
 char *aq_host;
 
 int udp = 0;			/* 0 = tcp, !0 = udp */
@@ -231,7 +232,7 @@ int no_check = 0;
 	    port_name = optarg;
 	    break;
 	  case 'P':
-	    pcr = atoi(optarg);
+	    qos_spec = optarg;
 	    break;
 	  case 'u':
 	    udp = 1;
@@ -287,7 +288,9 @@ int no_check = 0;
     }
 
     if (atm || (arequipa && trans)) {
-	memset(satm,0,sizeof(satm));
+	char *end;
+
+	memset(&satm,0,sizeof(satm));
 	if (!host) satm.sas_family = AF_ATMSVC;
 	else if (text2atm(atm ? host : aq_host,(struct sockaddr *) &satm,
 	      sizeof(satm),T2A_PVC | T2A_SVC | T2A_NAME) < 0) {
@@ -295,13 +298,22 @@ int no_check = 0;
 		exit(1);
 	    }
 	memset(&qos,0,sizeof(qos));
-	if (!trans) qos.rxtp.traffic_class = ATM_UBR;
-	else if (!pcr) qos.txtp.traffic_class = ATM_UBR;
-	    else {
-		qos.txtp.traffic_class = ATM_CBR;
-		qos.txtp.max_pcr = pcr;
+	if (!arequipa) qos.rxtp.max_sdu = qos.txtp.max_sdu = buflen;
+	if (qos_spec && ((pcr = strtol(qos_spec,&end,10)), *end)) {
+	    if (text2qos(qos_spec,&qos,T2Q_DEFAULTS) < 0) {
+		fprintf(stderr,"invalid QOS specification\n");
+		exit(1);
 	    }
-	qos.rxtp.max_sdu = qos.txtp.max_sdu = buflen;
+	}
+	else {
+	    if (!qos_spec) pcr = 0;
+	    if (!trans) qos.rxtp.traffic_class = ATM_UBR;
+	    else if (!pcr) qos.txtp.traffic_class = ATM_UBR;
+		else {
+		    qos.txtp.traffic_class = ATM_CBR;
+		    qos.txtp.max_pcr = pcr;
+		}
+	}
 	if (arequipa && !udp) qos.rxtp = qos.txtp;
     }
     if (!atm && trans)  {
